"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Handler = void 0;
const typescript_aws_apigateway_helper_1 = require("typescript-aws-apigateway-helper");
const typescript_aws_cloudwatch_helper_1 = require("typescript-aws-cloudwatch-helper");
const typescript_aws_dynamo_helper_1 = require("typescript-aws-dynamo-helper");
const typescript_aws_kms_helper_1 = require("typescript-aws-kms-helper");
const typescript_aws_lambda_helper_1 = require("typescript-aws-lambda-helper");
const typescript_aws_s3_helper_1 = require("typescript-aws-s3-helper");
const typescript_aws_ses_helper_1 = require("typescript-aws-ses-helper");
const typescript_aws_sns_helper_1 = require("typescript-aws-sns-helper");
const typescript_aws_sqs_helper_1 = require("typescript-aws-sqs-helper");
const typescript_aws_ssm_helper_1 = require("typescript-aws-ssm-helper");
const typescript_aws_sts_helper_1 = require("typescript-aws-sts-helper");
const typescript_ilogger_1 = require("typescript-ilogger");
const typescript_helper_functions_1 = require("typescript-helper-functions");
class Handler {
    constructor(LogLevel) {
        this.LogLevel = LogLevel;
        this.Logger = new typescript_ilogger_1.Logger(this.LogLevel);
        this.APIGatewayHelper = new typescript_aws_apigateway_helper_1.APIGatewayHelper(this.Logger);
        this.CloudWatchHelper = new typescript_aws_cloudwatch_helper_1.CloudWatchHelper(this.Logger);
        this.DynamoHelper = new typescript_aws_dynamo_helper_1.DynamoHelper(this.Logger);
        this.KMSHelper = new typescript_aws_kms_helper_1.KMSHelper(this.Logger);
        this.LambdaHelper = new typescript_aws_lambda_helper_1.LambdaHelper(this.Logger);
        this.S3Helper = new typescript_aws_s3_helper_1.S3Helper(this.Logger);
        this.SESHelper = new typescript_aws_ses_helper_1.SESHelper(this.Logger);
        this.SNSHelper = new typescript_aws_sns_helper_1.SNSHelper(this.Logger);
        this.SQSHelper = new typescript_aws_sqs_helper_1.SQSHelper(this.Logger);
        this.SSMHelper = new typescript_aws_ssm_helper_1.SSMHelper(this.Logger);
        this.STSHelper = new typescript_aws_sts_helper_1.STSHelper(this.Logger);
        this.LogHelper = new typescript_helper_functions_1.LogHelper(this.Logger);
        this.ObjectOperations = new typescript_helper_functions_1.ObjectOperations();
    }
    async Execute(payload, context, callback, actionToExecute) {
        const action = `${Handler.name}.${this.Execute.name}`;
        this.LogHelper.LogInputs(action, { payload, context, callback });
        if (this.ObjectOperations.IsNullOrEmpty(context)) {
            throw new Error(`[${action}]-Must supply context`);
        }
        let result;
        let error;
        try {
            result = await actionToExecute();
            this.Logger.Trace(`[${action}]-${JSON.stringify(result)}`);
        }
        catch (err) {
            error = err;
            this.Logger.Error(`[${action}]-${JSON.stringify(error)}`);
        }
        finally {
            callback(error, result);
        }
    }
    async Orchestrate(actionToExecute) {
        const action = `${Handler.name}.${this.Orchestrate.name}`;
        let result;
        try {
            this.Logger.Information(`[${action}]-Starting orchestration...`);
            result = await actionToExecute();
        }
        finally {
            this.Logger.Information(`[${action}]-Finished orchestration...`);
        }
        return result;
    }
    async OrchestrateSQS(records, queueUrl, actionToExecute) {
        const action = `${Handler.name}.${this.OrchestrateSQS.name}`;
        if (this.ObjectOperations.IsNullOrWhitespace(queueUrl)) {
            throw new Error(`[${action}]-Must supply queueUrl`);
        }
        await this.Orchestrate(async () => {
            for (const record of records) {
                this.Logger.Trace(`[${action}]-Record Body: ${record.body}`);
                await actionToExecute();
                await this.SQSHelper.DeleteMessageAsync(queueUrl, record.receiptHandle);
            }
        });
    }
}
exports.Handler = Handler;
//# sourceMappingURL=handler.js.map